@@ -83,6 +83,20 @@ sub clear_history {
     return;
 }
 
+# get the max level from a log, return as a string
+sub get_max_level {
+    my ( $self ) = @_;
+
+    my %levels = reverse Zonemaster::Logger::Entry->levels();
+    my $level = 0;
+
+    foreach ( @{ $self->entries } ) {
+	$level = $_->numeric_level if $_->numeric_level > $level;
+    }
+
+    return $levels{ $level };
+}
+
 sub json {
     my ( $self, $min_level ) = @_;
     my $json    = JSON::XS->new->allow_blessed->convert_blessed->canonical;
@@ -162,6 +176,10 @@ Returns a JSON-formatted string with all the stored log entries. If an argument
 is given and is a known severity level, only messages with at least that level
 will be included.
 
+=item get_max_level
+
+Returns the maximum log level from the entire log as the level string.
+
 =back
 
 =head1 CLASS METHOD
